# jQuery UI Shake Effect

## Overview

Shakes the element multiple times, vertically or horizontally.

### Dependencies

- Effects Core

### Example

- Demo
- View Source

Shakes 3 times when clicking on the element.

    $("div").click(function () {
          $(this).effect("shake", { times:3 }, 300);
    });

    <!DOCTYPE html>
    <html>
    <head>
      <link href="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/themes/base/jquery-ui.css" rel="stylesheet" type="text/css"/>
      <script src="http://ajax.googleapis.com/ajax/libs/jquery/1.4/jquery.min.js"></script>
      <script src="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/jquery-ui.min.js"></script>
      <style type="text/css">
      div { margin: 0px; width: 100px; height: 80px; background: green; border: 1px solid black; position: relative; }
    </style>

      <script>
      $(document).ready(function() {

    $("div").click(function () {
          $(this).effect("shake", { times:3 }, 300);
    });

      });
      </script>
    </head>
    <body style="font-size:62.5%;">
      <p></p><p></p><p></p><p></p><div></div>
    </body>
    </html>

## Arguments

- ### direction

  Type:
    String
  Default:
    "left"

  The direction of the effect. Can be "up", "down", "left", "right".

- ### distance

  Type:
    Integer
  Default:
    20

  Distance to shake.

- ### times

  Type:
    Integer
  Default:
    3

  Times to shake.